

#    MIDAS Access Client  for the  VHSADC service

package require MIDASAccessClient    ;#   load default support procedures

global VHSADCHost VHSADCPort

if {[info exists VHSADCHost] == 0} then {set VHSADCHost localhost}
if {[info exists VHSADCPort] == 0} then {set VHSADCPort 8015}

variable uri "urn:VHSADC"
variable proxy "http://$VHSADCHost:$VHSADCPort/VHSADC"

proc VHSADCClient_Configure {} {
   global VHSADCHost VHSADCPort
   variable proxy

   set proxy "http://$VHSADCHost:$VHSADCPort/VHSADC"

   foreach method [info procs VHSADCClient__*] {catch {SOAP::configure $method -proxy $proxy}}
}

proc VHSADCClient_SetUpTemp {} {
   global env 

   if {![info exists env(MIDASTempDir)] || ![file exists $env(MIDASTempDir)]} then {
       switch $env(os) {
          Win {set env(MIDASTempDir) [file join c:/ temp]}
          default {set env(MIDASTempDir) \tmp}
       }
   }

   catch {file mkdir $env(MIDASTempDir}
   catch {file mkdir [file join $env(MIDASTempDir) VHSADCClient]}
}

proc VHSADCClient_VHSADCUpLoad {file} {
    global env

    VHSADCClient_SetUpTemp

    set path [file join $env(MIDASTempDir) VHSADCClient [file tail $file].base64]

    switch $env(os) {
      SunOS -
      Win     {set z [catch {exec base64 --encode $file $path} m]}
      Linux64 -
      Linux   {set z [catch {exec base64 $file > $path} m]}
      default {set z -1; set m "Unsupported OS: $env(os)"}
    }
    if {$z != 0} then {midas-warning "Error in base64 encoding $file in VHSADCUpLoad\n$m"; return}

    set z [catch {open $path r} f]
    if {$z != 0} then {midas-warning "Cannot open file $path\n$f"; return}
    set contents [read $f]
    close $f

    VHSADCClient__VHSADCUpLoad $file $contents
}


SOAP::create VHSADCClient__VHSADCInit -proxy $proxy -uri $uri -timeout 5000 \
     -name VHSADCInit \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply 

SOAP::create VHSADCClient__VHSADCUpLoad -proxy $proxy -uri $uri -timeout 20000 \
     -name VHSADCUpLoad \
     -params {file string contents string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16FpgaReset -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16FpgaReset \
     -params {id int bitstream string int len}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16FpgaLoad -proxy $proxy -uri $uri -timeout 20000 \
     -name Vhsadac16FpgaLoad \
     -params {id int bitstream string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16ReadFpgaReg -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16ReadFpgaReg \
     -params {id int register int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16ReadFpgaRegs -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16ReadFpgaRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__ReadUserRegs -proxy $proxy -uri $uri -timeout 5000 \
     -name VHSADCClientReadUserRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16WriteFpgaReg -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16WriteFpgaReg \
     -params {id int register int value int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

package require rpcvar
namespace import -force rpcvar::typedef

typedef {
   register int
   value int
} itemStruct

SOAP::create VHSADCClient__Vhsadac16WriteFpgaRegs -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16WriteFpgaRegs \
     -params {id int registers itemStruct()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__WriteUserRegs -proxy $proxy -uri $uri -timeout 5000 \
     -name VHSADCClientWriteUserRegs \
     -params {id int registers int()}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16WriteFpgaMem -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16WriteFpgaMem \
     -params {id int offset int len int data string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16ReadFpgaMem -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16ReadFpgaMem \
     -params {id int offset int len int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16GetCpldRegs -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16GetCpldRegs \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_AutoInit -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_AutoInit \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Clock_Frequency -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Clock_Frequency \
     -params {id int freq int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_Frequency -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_Frequency \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_Size -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_Size \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_SinglePageMode -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_SinglePageMode \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_DualPageMode -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_DualPageMode \
     -params {id int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_Write -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_Write \
     -params {id int offset int len int data string}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__Vhsadac16Sdram_Read -proxy $proxy -uri $uri -timeout 5000 \
     -name Vhsadac16Sdram_Read \
     -params {id int offset int len int}  \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__VHSADCExit -proxy $proxy -uri $uri -timeout 5000 \
     -name VHSADCExit \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply

SOAP::create VHSADCClient__VHSADCVerbose -proxy $proxy -uri $uri -timeout 5000 \
     -name VHSADCVerbose \
     -params {opt int} \
     -wrapProc  ::SOAP::MIDAS_SOAPAccessClient_Request \
     -parseProc ::SOAP::MIDAS_SOAPAccessClient_Reply 



package provide VHSADCClient 1.0
