

#    Generic Run Control Application Implementation file
#    Assumes there is a SYS interpreter which has loaded the sys.WWW.tcl support file (or an application specific equivalent)

    package require DataAcquisitionControlServer   ;# load generic code


# do what's needed to setup all hardware
proc do_Implementation-SetUp {args} {
       global MIDAS_DataAcquisitionCode MIDAS_DataAcquisitionState MIDAS_DataAcquisitionReason
       global MIDAS_DataAcquisitionError MIDAS_DataAcquisitionInfo

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-SetUp with args $args"}

        set z [catch {inform sys do_Setup $args} m]
        if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-SetUp returned z=$z and $m"}

        if {$z != 0} {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "SETUP returned with an error\n$m"
            } 

            puts "SETUP returned with an error\n$m"

            set MIDAS_DataAcquisitionCode 6
        } else {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "SETUP returned $m"
            } 
#            set MIDAS_DataAcquisitionCode 0   -  state set by SYS application
        }
}

# do what's needed to reset all hardware
proc do_Implementation-Reset {args} {
     global MIDAS_DataAcquisitionCode

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-Reset with args $args"}

     set z [catch {inform sys do_Reset $args} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-Reset returned z=$z and $m"}

       if {$z != 0} {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "RESET returned with an error\n$m"
            } 

            puts "RESET returned with an error\n$m"

            set MIDAS_DataAcquisitionCode 6
        } else {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "RESET returned $m"
            } 
#            set MIDAS_DataAcquisitionCode 0   -  state set by SYS application
        }
}

# do what's needed to stop all "going" hardware streams
proc do_Implementation-Stop {args} {
     global MIDAS_DataAcquisitionCode

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-Stop with args $args"}

     set z [catch {inform sys do_Stop $args} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-Stop returned z=$z and $m"}

       if {$z != 0} {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "STOP returned with an error\n$m"
            } 

            puts "STOP returned with an error\n$m"

            set MIDAS_DataAcquisitionCode 6
        } else {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "STOP returned $m"
            } 
#            set MIDAS_DataAcquisitionCode 0   -  state set by SYS application
        }
}

# do what's needed to start all halted hardware streams
proc do_Implementation-Go {args} {
     global MIDAS_DataAcquisitionCode

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-Go with args $args"}

     set z [catch {inform sys do_Go $args} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-Go returned z=$z and $m"}

       if {$z != 0} {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "GO returned with an error\n$m"
            } 

            puts "GO returned with an error\n$m"

            set MIDAS_DataAcquisitionCode 6
        } else {

            if {[info procs ::DefineMessage] == "::DefineMessage"} {
               ::DefineMessage -c AcqControl -l INFORMATION  "GO returned $m"
            } 
#            set MIDAS_DataAcquisitionCode 0   -  state set by SYS application
        }
}

# do what's needed to set Data Acq program control options
proc do_Implementation-SetOption {args} {
     global MIDAS_DataAcquisitionCode

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-SetOption with args $args"}

     set z [catch {inform sys do_SetOption $args} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-SetOption returned z=$z and $m"}
}

# do what's needed to get Data Acq program control options
proc do_Implementation-GetOption {args} {
     global MIDAS_DataAcquisitionOption

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-GetOption with args $args"}

     set z [catch {inform sys do_GetOption $args} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-GetOption returned z=$z and $m"}

     return $m
}

# Not implemented
proc do_Implementation-Counters {} {
       global MIDAS_DataAcquisitionCounters
}

# Not implemented
proc do_Implementation-Rates {} {
       global MIDAS_DataAcquisitionRates
}

proc do_Implementation-GetState {} {
     global MIDAS_DataAcquisitionCode

     global MIDAS_DataAcquisitionControlServer_Verbose;
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "Entered do_Implementation-GetState"}

     set z [catch {inform sys Get_State} m]
     if {$MIDAS_DataAcquisitionControlServer_Verbose} {puts "do_Implementation-GetState returned z=$z and $m"}

      if {$z != 0} {

         set MIDAS_DataAcquisitionCode 6
      } else {

         set MIDAS_DataAcquisitionCode [first $m]
      }
}
package provide RunControl 1.0

puts "Run Control Implementation"
